@@ -5,7 +5,7 @@ from mlflow.tracking.context.abstract_context import RunContextProvider
 from mlflow.utils.mlflow_tags import MLFLOW_SOURCE_NAME, MLFLOW_SOURCE_TYPE, MLFLOW_USER
 
 
-def _get_user(self):
+def _get_user():
     return os.environ.get("JUPYTERHUB_USER", default="unknown")
 
 
@@ -20,5 +20,5 @@ class KozaiNotebookRunContext(RunContextProvider):
         return {
             MLFLOW_USER: _get_user(),
             MLFLOW_SOURCE_NAME: "Kozai Notebook",
-            MLFLOW_SOURCE_TYPE: SourceType.to_string(SourceType.NOTEBOOK()),
+            MLFLOW_SOURCE_TYPE: SourceType.to_string(SourceType.NOTEBOOK),
         }
